{% extends "base.html" %}
{% load i18n %}
{% block title %}{% trans "Confirm project invitation" %}{% endblock %}

{% block body_id %}splash{% endblock %}

{% block content %}
  {% include 'token/_tokenconfirm.html' %}
{% endblock %}

{% comment %}Explicitly redeclare the piwik block as empty{% endcomment %}
{% block piwik %}{% endblock %}
