# The slug of the panel to be added to HORIZON_CONFIG. Required.
PANEL = 'quota'
# The slug of the dashboard the PANEL associated with. Required.
PANEL_DASHBOARD = 'management'

PANEL_GROUP = 'default'

# Python panel class of the PANEL to be added.
ADD_PANEL = 'adjutant_ui.content.quota.panel.QuotaPanel'
