{% extends "horizon/common/_modal_form.html" %}
{% load i18n %}

{% block modal_id %}update_user_form{% endblock %}

{% block modal-body %}
    {% include "horizon/common/_form_fields.html" %}
{% endblock %}
