{% load i18n %}

{% block pre_login %}
<form id="" class="ng-pristine ng-valid ng-scope"
      method="POST"
      action="{% url 'horizon:token:token:token_verify' token=token %}"
      autocomplete="off"
      ng-controller="hzLoginController">
  {% csrf_token %}
{% endblock %}

  <div class="panel panel-default">

    <div class="panel-heading">
    {% block login_header %}
      <h3 class="login-title">
        {% trans 'Confirm project invitation' %}
      </h3>
    {% endblock %}
    </div>

    <div class="panel-body">
    {% block login_body %}
      You have been invited to join a project.
    {% endblock %}
    </div>

    <div class="panel-footer">
      {% block login_footer %}
        <button id="tokenBtn" type="submit" class="btn btn-primary">{% trans "Accept Invitation" %}</button>
        <div class="clearfix"></div>
      {% endblock %}
    </div>
  </div>

{% block post_login%}
</form>
{% endblock %}
