{% load i18n %}

<h4>{% trans "Roles:" %}</h4>
<p>{% trans "The “Project Administrator” role allows users to have full control over your project, including adding moderators and inviting other people to join it." %}</p>
<p>{% trans "The “Project Moderator” role can invite other people to join your project and update their roles, but cannot change the project admin." %}</p>
<p>{% trans "The “Project Member” role gives people access to all services on your project, but does not allow them to invite other people to join the project or update roles." %}</p>
