# Making use of this to make a generic enabled file
# to load base adjutant-ui content.
FEATURE = "adjutant-ui-base"

# A list of applications to be added to INSTALLED_APPS.
ADD_INSTALLED_APPS = [
    'adjutant_ui',
]
