{% extends "horizon/common/_modal_form.html" %}
{% load i18n %}

{% block modal_id %}invite_user_form{% endblock %}
{% block modal-header %}{% trans "Invite User" %}{% endblock %}
{% block form_action %}{% url 'horizon:management:project_users:invite' %}{% endblock %}

{% block modal-body %}
  <div class="left">
    <fieldset>
      {% include "horizon/common/_form_fields.html" %}
    </fieldset>
  </div>
  <div class="right">
    <h3>{% trans "Description:" %}</h3>
    <p>{% trans "Invite a person to join your project. If the user does not exist they will be emailed instructions to set up their account then automatically added to your project." %}</p>

    {% include 'management/project_users/_role_help.html' %}
  </div>
{% endblock %}

{% block modal-footer %}
    <button type="submit" class="btn btn-primary">{% trans "Invite" %}</button>
    <a href="{% url 'horizon:management:project_users:index' %}" class="btn btn-default secondary cancel pull-left">{% trans "Cancel" %}</a>
{% endblock %}
