# The slug of the panel to be added to HORIZON_CONFIG. Required.
PANEL = 'email'
# The slug of the dashboard the PANEL associated with. Required.
PANEL_DASHBOARD = 'settings'
# The slug of the panel group the PANEL is associated with.
PANEL_GROUP = 'default'

# Python panel class of the PANEL to be added.
ADD_PANEL = 'adjutant_ui.content.email.panel.EmailPanel'
