{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans "Admin Notifications" %}{% endblock %}

{% block main %}
<div class="row">
    <div class="col-sm-12">
      {{ tab_group.render }}
    </div>
</div>
{% endblock %}
