# The name of the dashboard to be added to HORIZON['dashboards']. Required.
DASHBOARD = 'token'

# A list of applications to be added to INSTALLED_APPS.
ADD_INSTALLED_APPS = [
    'adjutant_ui.dashboards.token_dash',
    'adjutant_ui.content.token',
]
